@@ -97,7 +97,7 @@ def init():
 
         print(response.status_code)
         # print(response.json())
-        print("flag1")
+        # print("flag1")
         name = data["project"]["repo"]["full_name"].split('/')
         token = data["project"]["githubtoken"]
         username = name[0]
@@ -119,20 +119,20 @@ def init():
         
         # Serializing json 
         json_object = json.dumps(dictionary, indent = 4)
-        print("fla21")
+        # print("fla21")
         # Writing to sample.json
         with open(project_id+'.json',"w") as outfile:
             outfile.write(json_object)
         
     
-        print("flag3")
+        # print("flag3")
         with open(project_id+'.json') as f:
          data = json.load(f)
          username = data["username"]
          token=data["token"]
          repo_name=data["repo_name"]
           
-        print("flag4")
+        # print("flag4")
 
         access_token =token #"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"
         OWNER = username #"AkashAi7" # github account name
@@ -157,9 +157,20 @@ def init():
           repo.create_hook("web", config, EVENTS, active=True)
          
         #   pull
-          repo = git.Repo(path)
-          origin = repo.remote(name='origin')
-          res=origin.pull()
+          response = requests.get('http://35.225.89.124/push_commit')
+          res=response.content
+        #   res=str(res)
+        #   index=res.index("Repository")
+        #   index1 = data.index(":",index+1)
+        #   index2 = data.index("\n",index1+1)
+        #   repoN = data[index1 + 1:index2]
+        #   print(repoN)
+          print(len(res))
+          val=len(res)
+          if val >0:
+            repo = git.Repo(path)
+            origin = repo.remote(name='origin')
+            res=origin.pull()
           response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name})
            #success , project id , repo name , current date and time , email id
           print("status code is ",response2.status_code)
@@ -167,10 +178,26 @@ def init():
         except:
             print("webhook already exists on this repository ")
 
-                 #   pull
-            repo = git.Repo(path)
-            origin = repo.remote(name='origin')
-            res=origin.pull()
+            #   pull
+            response = requests.get('http://35.225.89.124/push_commit')
+            res=response.content
+            print(res)
+            val=len(res)
+            print(val)
+            data=str(res)
+            print("inside except")
+            # index=data.index("Repository")
+            # index1 = data.index(":",index+1)
+            # index2 = data.index("\n",index1+1)
+            # repoN = data[index1 + 1:index2]
+            # print(repoN)
+            if val >0:
+                repo = git.Repo(path)
+                origin = repo.remote(name='origin')
+                res=origin.pull()
+                print("pull succeessfull")
+            else:
+                print("no files to pull")
             time = datetime.datetime.now()
             response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':time,'user_name':username})
            #success , project id , repo name , current date and time , email id'
